@@ -62,6 +62,13 @@ bonobo_socket_atk_object_get_accessible (SpiRemoteObject *remote)
   return retval;
 }
 
+static void
+bonobo_control_frame_destroy_notify (gpointer object,
+				     GObject *frame)
+{
+  g_object_set_qdata (G_OBJECT (object), quark_private_frame, NULL);
+}
+
 static void
 bonobo_socket_finalize (GObject *object)
 {
@@ -69,7 +76,7 @@ bonobo_socket_finalize (GObject *object)
 
   frame = bonobo_socket_atk_object_get_frame (BONOBO_SOCKET_ATK_OBJECT (object));
   if (frame) {
-    g_object_unref (G_OBJECT (frame));
+    g_object_weak_unref (G_OBJECT (frame), bonobo_control_frame_destroy_notify, object);
     g_object_set_qdata (object, quark_private_frame, NULL);
   }
 }
@@ -155,7 +162,7 @@ bonobo_socket_atk_object_new (BonoboSocket *socket)
 
   if (socket->frame)
     {
-      g_object_ref (G_OBJECT (socket->frame));
+      g_object_weak_ref (G_OBJECT (socket->frame), bonobo_control_frame_destroy_notify, retval);
 
       g_object_set_qdata (G_OBJECT (retval), quark_private_frame, socket->frame);
     }
